@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -20,6 +20,7 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import typing as tp
+from typing import TypeAlias
 
 # Bokeh imports
 from .bases import Init, SingleParameterizedProperty
@@ -28,9 +29,6 @@ from .either import Either
 from .primitive import String
 from .singletons import Intrinsic
 
-if tp.TYPE_CHECKING:
-    from typing_extensions import TypeAlias
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -48,8 +46,8 @@ L1Factor = String
 L2Factor = Tuple(String, String)
 L3Factor = Tuple(String, String, String)
 
-FactorType: TypeAlias = tp.Union[str, tp.Tuple[str, str], tp.Tuple[str, str]]
-FactorSeqType: TypeAlias = tp.Union[tp.Sequence[str], tp.Sequence[tp.Tuple[str, str]], tp.Sequence[tp.Tuple[str, str]]]
+FactorType: TypeAlias = str | tuple[str, str] | tuple[str, str]
+FactorSeqType: TypeAlias = tp.Sequence[str] | tp.Sequence[tuple[str, str]] | tp.Sequence[tuple[str, str]]
 
 class Factor(SingleParameterizedProperty[FactorType]):
     """ Represents a single categorical factor. """
