@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -30,8 +30,8 @@ event object that triggered the callback.
 
 Alternatively it is possible to trigger Python code to run when events
 happen, in the context of a Bokeh application running on a Bokeh server.
-This can accomplished by passing an event class, and a callback function
-to the the :func:`~bokeh.model.Model.on_event` method. The callback should
+This can be accomplished by passing an event class, and a callback function
+to the :func:`~bokeh.model.Model.on_event` method. The callback should
 accept a single argument ``event``, which will be passed the concrete
 event object that triggered the callback.
 
@@ -76,11 +76,12 @@ from typing import (
 )
 
 # Bokeh imports
-from .core.serialization import Deserializer
+from .core.serialization import Deserializer, Serializable, Serializer
 
 if TYPE_CHECKING:
     from .core.types import GeometryData
     from .model import Model
+    from .models.annotations import Legend, LegendItem
     from .models.plots import Plot
     from .models.widgets.buttons import AbstractButton
     from .models.widgets.inputs import TextInput
@@ -98,6 +99,7 @@ __all__ = (
     'Event',
     'LODEnd',
     'LODStart',
+    'LegendItemClick',
     'MenuItemClick',
     'ModelEvent',
     'MouseEnter',
@@ -134,12 +136,17 @@ _CONCRETE_EVENT_CLASSES: dict[str, type[Event]] = {}
 # General API
 #-----------------------------------------------------------------------------
 
+class KeyModifiers(TypedDict):
+    shift: bool
+    ctrl: bool
+    alt: bool
+
 class EventRep(TypedDict):
     type: Literal["event"]
     name: str
     values: dict[str, Any]
 
-class Event:
+class Event(Serializable):
     ''' Base class for all Bokeh events.
 
     This base class is not typically useful to instantiate on its own.
@@ -162,6 +169,16 @@ class Event:
         if hasattr(cls, "event_name"):
             _CONCRETE_EVENT_CLASSES[cls.event_name] = cls
 
+    def event_values(self) -> dict[str, Any]:
+        return {}
+
+    def to_serializable(self, serializer: Serializer) -> BokehEventRep:
+        return BokehEventRep(
+            type="event",
+            name=self.event_name,
+            values=serializer.encode(self.event_values()),
+        )
+
     @classmethod
     def from_serializable(cls, rep: EventRep, decoder: Deserializer) -> Event:
         if not ("name" in rep and "values" in rep):
@@ -255,6 +272,8 @@ class ModelEvent(Event):
         '''
         self.model = model
 
+    def event_values(self) -> dict[str, Any]:
+        return dict(**super().event_values(), model=self.model)
 
 class ButtonClick(ModelEvent):
     ''' Announce a button click event on a Bokeh button widget.
@@ -264,11 +283,21 @@ class ButtonClick(ModelEvent):
 
     def __init__(self, model: AbstractButton | None) -> None:
         from .models.widgets import AbstractButton, ToggleButtonGroup
-        if model is not None and not isinstance(model, (AbstractButton, ToggleButtonGroup)):
+        if model is not None and not isinstance(model, AbstractButton | ToggleButtonGroup):
             clsname = self.__class__.__name__
             raise ValueError(f"{clsname} event only applies to button and button group models")
         super().__init__(model=model)
 
+class LegendItemClick(ModelEvent):
+    ''' Announce a click event on a Bokeh legend item.
+
+    '''
+    event_name = 'legend_item_click'
+
+    def __init__(self, model: Legend, item: LegendItem) -> None:
+        self.item = item
+        super().__init__(model=model)
+
 class MenuItemClick(ModelEvent):
     ''' Announce a button click event on a Bokeh menu item.
 
@@ -394,16 +423,24 @@ class PointEvent(PlotEvent):
         y (float) : y-coordinate of the event in *data* space
 
     Note that data space coordinates are relative to the default range, not
-    any extra ranges, and the the screen space origin is at the top left of
+    any extra ranges, and the screen space origin is at the top left of
     the HTML canvas.
 
     '''
-    def __init__(self, model: Plot | None, sx: float | None = None, sy:
-            float | None = None, x: float | None = None, y: float | None = None):
+    def __init__(
+        self,
+        model: Plot | None,
+        sx: float | None = None,
+        sy: float | None = None,
+        x: float | None = None,
+        y: float | None = None,
+        modifiers: KeyModifiers | None = None,
+    ):
         self.sx = sx
         self.sy = sy
         self.x = x
         self.y = y
+        self.modifiers = modifiers
         super().__init__(model=model)
 
 class Tap(PointEvent):
@@ -528,9 +565,10 @@ class MouseWheel(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.delta = delta
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class Pan(PointEvent):
     ''' Announce a pan event on a Bokeh plot.
@@ -556,11 +594,12 @@ class Pan(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.delta_x = delta_x
         self.delta_y = delta_y
         self.direction = direction
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class PanEnd(PointEvent):
     ''' Announce the end of a pan event on a Bokeh plot.
@@ -609,9 +648,10 @@ class Pinch(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.scale = scale
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class PinchEnd(PointEvent):
     ''' Announce the end of a pinch event on a Bokeh plot.
@@ -666,9 +706,10 @@ class Rotate(PointEvent):
             sx: float | None = None,
             sy: float | None = None,
             x: float | None = None,
-            y: float | None = None):
+            y: float | None = None,
+            modifiers: KeyModifiers | None = None):
         self.rotation = rotation
-        super().__init__(model, sx=sx, sy=sy, x=x, y=y)
+        super().__init__(model, sx=sx, sy=sy, x=x, y=y, modifiers=modifiers)
 
 class RotateEnd(PointEvent):
     ''' Announce the end of a rotate event on a Bokeh plot.
@@ -704,6 +745,11 @@ class RotateStart(PointEvent):
 # Dev API
 #-----------------------------------------------------------------------------
 
+class BokehEventRep(TypedDict):
+  type: Literal["event"]
+  name: str
+  values: Any
+
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
