@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -43,6 +43,8 @@ from .util import (
 )
 
 if TYPE_CHECKING:
+    from typing_extensions import Self
+
     from ..core.has_props import Setter
     from ..core.query import SelectorType
     from ..document import Document
@@ -94,7 +96,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
 
     _id: ID
 
-    def __new__(cls, *args: Any, id: ID | None = None, **kwargs: Any) -> Model:
+    def __new__(cls, *args: Any, id: ID | None = None, **kwargs: Any) -> Self:
         obj = super().__new__(cls)
 
         # Setting 'id' implies deferred initialization, which means properties
@@ -341,7 +343,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
             other_attr (str) :
                 The property on ``other`` to link together
 
-            attr_selector (Union[int, str]) :
+            attr_selector (int | str) :
                 The index to link an item in a subscriptable ``attr``
 
         Added in version 1.1
@@ -392,7 +394,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
             raise ValueError(f"{attr!r} is not a property of self ({self!r})")
 
         if not isinstance(other, Model):
-            raise ValueError("'other' is not a Bokeh model: %r" % other)
+            raise ValueError(f"'other' is not a Bokeh model: {other!r}")
 
         other_descriptor = other.lookup(other_attr, raises=False)
         if other_descriptor is None:
