@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,11 +21,8 @@ log = logging.getLogger(__name__)
 from typing import (
     TYPE_CHECKING,
     Any as TAny,
-    Dict as TDict,
-    List as TList,
     Sequence,
-    Tuple,
-    Union,
+    TypeAlias,
     overload,
 )
 
@@ -52,16 +49,14 @@ from ..core.properties import (
     String,
 )
 from ..model import Model
-from ..util.deprecation import deprecated
 from ..util.serialization import convert_datetime_array
 from ..util.warnings import BokehUserWarning, warn
 from .callbacks import CustomJS
-from .filters import AllIndices, Filter, IntersectionFilter
+from .filters import AllIndices, Filter
 from .selections import Selection, SelectionPolicy, UnionRenderers
 
 if TYPE_CHECKING:
     import pandas as pd
-    from typing_extensions import TypeAlias
 
     from ..core.has_props import Setter
 
@@ -87,11 +82,11 @@ __all__ = (
 if TYPE_CHECKING:
     import numpy.typing as npt
 
-    DataDict: TypeAlias = TDict[str, Union[Sequence[TAny], npt.NDArray[TAny], pd.Series, pd.Index]]
+    DataDict: TypeAlias = dict[str, Sequence[TAny] | npt.NDArray[TAny] | pd.Series | pd.Index]
 
-    Index: TypeAlias = Union[int, slice, Tuple[Union[int, slice], ...]]
+    Index: TypeAlias = int | slice | tuple[int | slice, ...]
 
-    Patches: TypeAlias = TDict[str, TList[Tuple[Index, Any]]]
+    Patches: TypeAlias = dict[str, list[tuple[Index, Any]]]
 
 @abstract
 class DataSource(Model):
@@ -120,6 +115,15 @@ class ColumnarDataSource(DataSource):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    default_values = Dict(String, Any, default={}, help="""
+    Defines the default value for each column.
+
+    This is used when inserting rows into a data source, e.g. by edit tools,
+    when a value for a given column is not explicitly provided. If a default
+    value is missing, a tool will defer to its own configuration or will try
+    to let the data source to infer a sensible default value.
+    """)
+
     selection_policy = Instance(SelectionPolicy, default=InstanceDefault(UnionRenderers), help="""
     An instance of a ``SelectionPolicy`` that determines how selections are set.
     """)
@@ -203,13 +207,13 @@ class ColumnDataSource(ColumnarDataSource):
     objects. In these cases, the behaviour is identical to passing the objects
     to the ``ColumnDataSource`` initializer.
     """).accepts(
-        Object("pandas.DataFrame"), lambda x: ColumnDataSource._data_from_df(x)
+        Object("pandas.DataFrame"), lambda x: ColumnDataSource._data_from_df(x),
     ).accepts(
-        Object("pandas.core.groupby.GroupBy"), lambda x: ColumnDataSource._data_from_groupby(x)
+        Object("pandas.core.groupby.GroupBy"), lambda x: ColumnDataSource._data_from_groupby(x),
     ).asserts(lambda _, data: len({len(x) for x in data.values()}) <= 1,
                  lambda obj, name, data: warn(
                     "ColumnDataSource's columns must be of the same length. " +
-                    "Current lengths: %s" % ", ".join(sorted(str((k, len(v))) for k, v in data.items())), BokehUserWarning))
+                    f"Current lengths: {', '.join(sorted(str((k, len(v))) for k, v in data.items()))}", BokehUserWarning))
 
     @overload
     def __init__(self, data: DataDict | pd.DataFrame | pd.core.groupby.GroupBy, **kwargs: TAny) -> None: ...
@@ -512,7 +516,7 @@ class ColumnDataSource(ColumnarDataSource):
 
         needs_length_check = True
 
-        if isinstance(new_data, (pd.Series, pd.DataFrame)):
+        if isinstance(new_data, pd.Series | pd.DataFrame):
             if isinstance(new_data, pd.Series):
                 new_data = new_data.to_frame().T
 
@@ -555,7 +559,7 @@ class ColumnDataSource(ColumnarDataSource):
         # slightly awkward that we have to call convert_datetime_array here ourselves
         # but the downstream code expects things to already be ms-since-epoch
         for key, values in new_data.items():
-            if pd and isinstance(values, (pd.Series, pd.Index)):
+            if pd and isinstance(values, pd.Series | pd.Index):
                 values = values.values
             old_values = self.data[key]
             # Apply the transformation if the new data contains datetimes
@@ -667,7 +671,7 @@ class ColumnDataSource(ColumnarDataSource):
         extra = set(patches.keys()) - set(self.data.keys())
 
         if extra:
-            raise ValueError("Can only patch existing columns (extra: %s)" % ", ".join(sorted(extra)))
+            raise ValueError(f"Can only patch existing columns (extra: {', '.join(sorted(extra))})")
 
         for name, patch in patches.items():
 
@@ -687,7 +691,7 @@ class ColumnDataSource(ColumnarDataSource):
                         raise ValueError("Out-of bounds slice index stop (%d) in patch for column: %s" % (ind.stop, name))
 
                 # multi-index, patch sub-regions of "n-d" column
-                elif isinstance(ind, (list, tuple)):
+                elif isinstance(ind, list | tuple):
                     if len(ind) == 0:
                         raise ValueError("Empty (length zero) patch multi-index")
 
@@ -696,7 +700,7 @@ class ColumnDataSource(ColumnarDataSource):
 
                     ind_0 = ind[0]
                     if not isinstance(ind_0, int):
-                        raise ValueError("Initial patch sub-index may only be integer, got: %s" % ind_0)
+                        raise ValueError(f"Initial patch sub-index may only be integer, got: {ind_0}")
 
                     if ind_0 > col_len or ind_0 < 0:
                         raise ValueError("Out-of bounds initial sub-index (%d) in patch for column: %s" % (ind, name))
@@ -714,13 +718,13 @@ class ColumnDataSource(ColumnarDataSource):
 
                     # Note: bounds of sub-indices after the first are not checked!
                     for subind in ind[1:]:
-                        if not isinstance(subind, (int, slice)):
-                            raise ValueError("Invalid patch sub-index: %s" % subind)
+                        if not isinstance(subind, int | slice):
+                            raise ValueError(f"Invalid patch sub-index: {subind}")
                         if isinstance(subind, slice):
                             _check_slice(subind)
 
                 else:
-                    raise ValueError("Invalid patch index: %s" % ind)
+                    raise ValueError(f"Invalid patch index: {ind}")
 
         self.data._patch(self.document, self, patches, setter)
 
@@ -730,9 +734,6 @@ class CDSView(Model):
     '''
 
     def __init__(self, *args: TAny, **kwargs: TAny) -> None:
-        if "source" in kwargs:
-            del kwargs["source"]
-            deprecated("CDSView.source is no longer needed, and is now ignored. In a future release, passing source will result an error.")
         super().__init__(*args, **kwargs)
 
     filter = Instance(Filter, default=InstanceDefault(AllIndices), help="""
@@ -750,27 +751,6 @@ class CDSView(Model):
         cds_view.filter &= ~IndexFilter(indices=[10, 11])
     """)
 
-    @property
-    def filters(self) -> list[Filter]:
-        deprecated("CDSView.filters was deprecated in bokeh 3.0. Use CDSView.filter instead.")
-        filter = self.filter
-        if isinstance(filter, IntersectionFilter):
-            return filter.operands
-        elif isinstance(filter, AllIndices):
-            return []
-        else:
-            return [filter]
-
-    @filters.setter
-    def filters(self, filters: list[Filter]) -> None:
-        deprecated("CDSView.filters was deprecated in bokeh 3.0. Use CDSView.filter instead.")
-        if len(filters) == 0:
-            self.filter = AllIndices()
-        elif len(filters) == 1:
-            self.filter = filters[0]
-        else:
-            self.filter = IntersectionFilter(operands=filters)
-
 class GeoJSONDataSource(ColumnarDataSource):
     '''
 
@@ -910,11 +890,11 @@ class AjaxDataSource(WebDataSource):
 
 def _check_slice(s: slice) -> None:
     if (s.start is not None and s.stop is not None and s.start > s.stop):
-        raise ValueError("Patch slices must have start < end, got %s" % s)
+        raise ValueError(f"Patch slices must have start < end, got {s}")
     if (s.start is not None and s.start < 0) or \
        (s.stop  is not None and s.stop < 0) or \
        (s.step  is not None and s.step < 0):
-        raise ValueError("Patch slices must have non-negative (start, stop, step) values, got %s" % s)
+        raise ValueError(f"Patch slices must have non-negative (start, stop, step) values, got {s}")
 
 #-----------------------------------------------------------------------------
 # Code
