@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -29,8 +29,7 @@ from typing import (
     Any,
     Callable,
     Sequence,
-    Type,
-    Union,
+    TypeAlias,
     cast,
 )
 
@@ -39,8 +38,6 @@ from ..events import Event, ModelEvent
 from ..util.functions import get_param_info
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
-
     from ..core.has_props import Setter
     from ..core.types import ID
     from ..document.document import Document
@@ -64,7 +61,7 @@ __all__ = (
 # means auto-magically wrapping user-supplied callbacks for awhile.
 EventCallbackWithEvent: TypeAlias = Callable[[Event], None]
 EventCallbackWithoutEvent: TypeAlias = Callable[[], None]
-EventCallback: TypeAlias = Union[EventCallbackWithEvent, EventCallbackWithoutEvent]
+EventCallback: TypeAlias = EventCallbackWithEvent | EventCallbackWithoutEvent
 
 PropertyCallback: TypeAlias = Callable[[str, Any, Any], None]
 
@@ -83,7 +80,7 @@ class EventCallbackManager:
         super().__init__(*args, **kw)
         self._event_callbacks = defaultdict(list)
 
-    def on_event(self, event: str | Type[Event], *callbacks: EventCallback) -> None:
+    def on_event(self, event: str | type[Event], *callbacks: EventCallback) -> None:
         ''' Run callbacks when the specified event occurs on this Model
 
         Not all Events are supported for all Models.
@@ -206,14 +203,13 @@ def _nargs(fn: Callable[..., Any]) -> int:
 def _check_callback(callback: Callable[..., Any], fargs: Sequence[str], what: str ="Callback functions") -> None:
     '''Bokeh-internal function to check callback signature'''
     sig = signature(callback)
-    formatted_args = str(sig)
-    error_msg = what + " must have signature func(%s), got func%s"
-
     all_names, default_values = get_param_info(sig)
 
     nargs = len(all_names) - len(default_values)
     if nargs != len(fargs):
-        raise ValueError(error_msg % (", ".join(fargs), formatted_args))
+        expected = ", ".join(fargs)
+        received = str(sig)
+        raise ValueError(f"{what} must have signature func({expected}), got func{received}")
 
 #-----------------------------------------------------------------------------
 # Code
